import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:unicons/unicons.dart';

import '../../cubit/bottom_nav_cubit.dart';
import '../../cubit/settings_cubit.dart';

class SettingsForm extends StatefulWidget {
  const SettingsForm({super.key});

  @override
  State<SettingsForm> createState() => _SettingsFormState();
}

class _SettingsFormState extends State<SettingsForm> {
  final apiUrlController = TextEditingController();
  final securityTokenController = TextEditingController();

  @override
  void dispose() {
    apiUrlController.dispose();
    securityTokenController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    SettingsCubit settings = BlocProvider.of<SettingsCubit>(context);

    apiUrlController.text = settings.getSetting('apiUrl');
    securityTokenController.text = settings.getSetting('securityToken');

    void saveSettings() {
      BlocProvider.of<SettingsCubit>(context).setValues(
        apiUrl: apiUrlController.text,
        securityToken: securityTokenController.text,
      );

      BlocProvider.of<BottomNavCubit>(context).getDemoPage();
    }

    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisSize: MainAxisSize.max,
      children: <Widget>[
        Text('settings_label_api_url').tr(),
        TextFormField(
          controller: apiUrlController,
          decoration: InputDecoration(
            border: UnderlineInputBorder(),
          ),
        ),
        SizedBox(height: 16),
        Text('settings_label_security_token').tr(),
        TextFormField(
          controller: securityTokenController,
          decoration: InputDecoration(
            border: UnderlineInputBorder(),
          ),
        ),
        SizedBox(height: 16),
        ElevatedButton(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Icon(UniconsLine.save),
              SizedBox(width: 8),
              Text('settings_button_save').tr(),
            ],
          ),
          onPressed: () => saveSettings(),
        ),
      ],
    );
  }
}
